"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.accountUtils = void 0;
const util_1 = require("util");
const index_1 = require("../index");
class AccountUtil {
    static getAccountsProvisionApiUrl() {
        return `${AccountUtil.getProvisionApiUrl()}/sub_accounts`;
    }
    static getProvisionApiUrl() {
        const testRunData = index_1.testRunDataUtil.getData();
        return `https://${testRunData.provisioningKey}:${testRunData.provisioningSecret}@${testRunData.apiDomain}/v1_1/provisioning/accounts/${testRunData.provisioningAccountId}/`;
    }
    createSubAccount(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const options = {
                data: {
                    name: name ? name : (0, index_1.getRandomString)(10, true).toLowerCase(),
                },
            };
            index_1.Reporter.debug(`Creating new sub account with name ${options.data.name}`);
            const createAccountResponse = yield index_1.RequestUtils.postRequest(yield index_1.RequestUtils.getRequestContext(), `${AccountUtil.getAccountsProvisionApiUrl()}`, options);
            index_1.Reporter.debug(`New sub account data: '${(0, util_1.inspect)(yield createAccountResponse.json())}'`);
            return createAccountResponse;
        });
    }
    deleteSubAccount(subAccountId) {
        return __awaiter(this, void 0, void 0, function* () {
            index_1.Reporter.debug(`Deleting sub account with id ${subAccountId}`);
            const deleteAccountResponse = yield index_1.RequestUtils.deleteRequest(yield index_1.RequestUtils.getRequestContext(), `${AccountUtil.getAccountsProvisionApiUrl()}/${subAccountId}`);
            index_1.Reporter.debug(`Sub account with id ${subAccountId} was deleted with response: '${(0, util_1.inspect)(yield deleteAccountResponse.json())}'`);
        });
    }
    disableSubAccount(subAccountId) {
        return __awaiter(this, void 0, void 0, function* () {
            index_1.Reporter.debug(`Disabling sub account with id ${subAccountId}`);
            const disableSubAccountResponse = yield index_1.RequestUtils.putRequest(yield index_1.RequestUtils.getRequestContext(), `${AccountUtil.getAccountsProvisionApiUrl()}/${subAccountId}`, {
                data: { enabled: false },
            });
            index_1.Reporter.debug(`Sub account with id ${subAccountId} was disabled with response: '${(0, util_1.inspect)(yield disableSubAccountResponse.json())}'`);
        });
    }
}
const accountUtils = new AccountUtil();
exports.accountUtils = accountUtils;
//# sourceMappingURL=AccountUtils.js.map