"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RequestUtils = void 0;
const test_1 = require("@playwright/test");
const util_1 = require("util");
const index_1 = require("../index");
var RequestType;
(function (RequestType) {
    RequestType["GET"] = "GET";
    RequestType["POST"] = "POST";
    RequestType["HEAD"] = "HEAD";
    RequestType["DELETE"] = "DELETE";
    RequestType["PUT"] = "PUT";
})(RequestType || (RequestType = {}));
function prepareLogMessage(requestType, url, options) {
    return `Sending '${requestType}' request to url: '${url}' ${options !== undefined ? `with options:\n ${(0, util_1.inspect)(options)}` : ''}`;
}
var RequestUtils;
(function (RequestUtils) {
    function getRequestContext(options) {
        return __awaiter(this, void 0, void 0, function* () {
            index_1.Reporter.debug(`Creating new request context ${options !== undefined ? `with options:\n ${(0, util_1.inspect)(options)}` : ''}`);
            return test_1.request.newContext(options);
        });
    }
    RequestUtils.getRequestContext = getRequestContext;
    function getRequest(request, url, options) {
        return __awaiter(this, void 0, void 0, function* () {
            index_1.Reporter.debug(prepareLogMessage(RequestType.GET, url.toString(), options));
            return request.get(url, options);
        });
    }
    RequestUtils.getRequest = getRequest;
    function postRequest(request, url, options) {
        return __awaiter(this, void 0, void 0, function* () {
            index_1.Reporter.debug(prepareLogMessage(RequestType.POST, url, options));
            return request.post(url, options);
        });
    }
    RequestUtils.postRequest = postRequest;
    function putRequest(request, url, options) {
        return __awaiter(this, void 0, void 0, function* () {
            index_1.Reporter.debug(prepareLogMessage(RequestType.PUT, url, options));
            return request.put(url, options);
        });
    }
    RequestUtils.putRequest = putRequest;
    function headRequest(request, url, options) {
        return __awaiter(this, void 0, void 0, function* () {
            index_1.Reporter.debug(prepareLogMessage(RequestType.HEAD, url, options));
            return request.head(url, options);
        });
    }
    RequestUtils.headRequest = headRequest;
    function deleteRequest(request, url, options) {
        return __awaiter(this, void 0, void 0, function* () {
            index_1.Reporter.debug(prepareLogMessage(RequestType.DELETE, url, options));
            return request.delete(url, options);
        });
    }
    RequestUtils.deleteRequest = deleteRequest;
})(RequestUtils = exports.RequestUtils || (exports.RequestUtils = {}));
//# sourceMappingURL=RequestUtils.js.map